add_action('wp_ajax_generate_facebook_ad_ideas', 'generate_facebook_ad_ideas_handler');
add_action('wp_ajax_nopriv_generate_facebook_ad_ideas', 'generate_facebook_ad_ideas_handler');

if (!function_exists('generate_facebook_ad_ideas_handler')) {
    function generate_facebook_ad_ideas_handler() {
        // Check if the user is logged in
        if (!is_user_logged_in()) {
            wp_send_json_error('You must be logged in to use this tool.');
        }

        if (!isset($_POST['topic'])) {
            echo json_encode(['error' => 'Error: Topic not provided.']);
            wp_die();
        }

        $topic = sanitize_text_field($_POST['topic']);
        error_log('Received topic: ' . $topic);

        $ch = curl_init();

        // Webhook URL and data
        $webhook_url = 'WEBHOOK_URL';
        $data = array('topic' => $topic);

        // Set cURL options
        curl_setopt($ch, CURLOPT_URL, $webhook_url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/x-www-form-urlencoded'));

        // Execute the cURL request
        $response = curl_exec($ch);

        // Check for cURL errors
        if (curl_errno($ch)) {
            $curlError = curl_error($ch);
            error_log('cURL error: ' . $curlError);
            curl_close($ch);
            echo json_encode(['error' => 'Error: Failed to trigger webhook. cURL error: ' . $curlError]);
            wp_die();
        }

        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        error_log('HTTP response code: ' . $httpCode);
        error_log('Webhook response: ' . $response);

        // Check if the response is valid and contains ad ideas
        if ($httpCode >= 200 && $httpCode < 300) {
            echo json_encode(['ads' => $response]);
        } else {
            echo json_encode(['error' => 'Error: Webhook returned HTTP status ' . $httpCode . '. Response: ' . $response]);
        }

        wp_die();
    }
}
